import * as vscode from 'vscode';
import { ChatViewProvider } from './extension/ChatViewProvider';

// 创建一个输出通道用于日志记录
let outputChannel: vscode.OutputChannel;

// 日志记录函数
function log(message: string) {
  if (!outputChannel) {
    outputChannel = vscode.window.createOutputChannel('AI Chat Plugin');
  }

  const timestamp = new Date().toISOString();
  outputChannel.appendLine(`[${timestamp}] ${message}`);
}

export function activate(context: vscode.ExtensionContext) {
  // 创建输出通道
  outputChannel = vscode.window.createOutputChannel('AI Chat Plugin');
  outputChannel.show(true);

  log('VSCode AI Chat Plugin 已激活');

  // 注册Webview视图提供程序
  const chatViewProvider = new ChatViewProvider(context.extensionUri, log);
  context.subscriptions.push(
    vscode.window.registerWebviewViewProvider(
      ChatViewProvider.viewType,
      chatViewProvider
    )
  );

  // 注册打开聊天命令
  context.subscriptions.push(
    vscode.commands.registerCommand('vscode-ai-chat-plugin.openChat', () => {
      log('执行打开聊天命令');
      vscode.commands.executeCommand('workbench.view.extension.aiChatView');
    })
  );

  // 监听配置变更
  context.subscriptions.push(
    vscode.workspace.onDidChangeConfiguration(e => {
      if (e.affectsConfiguration('aiChat')) {
        log('AI聊天配置已更改');
      }
    })
  );
}

export function deactivate() {
  log('VSCode AI Chat Plugin 已停用');

  if (outputChannel) {
    outputChannel.dispose();
  }
}